"use strict";var e=function(r,t){return function(){return t||r((t={exports:{}}).exports,t),t.exports}};var a=e(function(u,n){
var s=require('@stdlib/utils-native-class/dist'),i=typeof Int16Array=="function";function o(r){return i&&r instanceof Int16Array||s(r)==="[object Int16Array]"}n.exports=o
});var y=a();module.exports=y;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
